@@ -3,7 +3,7 @@
 // handle shadow pixmaps passed to window manager via X property
 // -------------------
 //
-// Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+// Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -215,22 +215,22 @@ namespace Oxygen
     bool ShadowHelper::acceptWidget( QWidget* widget ) const
     {
 
+        // flags
         if( widget->property( netWMSkipShadowPropertyName ).toBool() ) return false;
         if( widget->property( netWMForceShadowPropertyName ).toBool() ) return true;
 
         // menus
-        if( qobject_cast<QMenu*>( widget ) ) return true;
+        if( isMenu( widget ) ) return true;
 
         // combobox dropdown lists
         if( widget->inherits( "QComboBoxPrivateContainer" ) ) return true;
 
         // tooltips
-        if( (widget->inherits( "QTipLabel" ) || (widget->windowFlags() & Qt::WindowType_Mask) == Qt::ToolTip ) &&
-            !widget->inherits( "Plasma::ToolTip" ) )
+        if( isToolTip( widget ) && !widget->inherits( "Plasma::ToolTip" ) )
         { return true; }
 
         // detached widgets
-        if( qobject_cast<QToolBar*>( widget ) || qobject_cast<QDockWidget*>( widget ) )
+        if( isDockWidget( widget ) || isToolBar( widget ) )
         { return true; }
 
         // reject
@@ -360,12 +360,34 @@ namespace Oxygen
 
         // add padding
         /*
-        all 4 paddings are identical, since offsets are handled when generating the pixmaps.
-        there is one extra pixel needed with respect to actual shadow size, to deal with how
-        menu backgrounds are rendered
+        in most cases all 4 paddings are identical, since offsets are handled when generating the pixmaps.
+        There is one extra pixel needed with respect to actual shadow size, to deal with how
+        menu backgrounds are rendered.
+        Some special care is needed for QBalloonTip, since the later have an arrow
         */
-        if( isToolTip( widget ) || isToolBar( widget ) )
+
+        if( isToolTip( widget ) )
         {
+            if( widget->inherits( "QBalloonTip" ) )
+            {
+
+                // balloon tip needs special margins to deal with the arrow
+                int top = 0;
+                int bottom = 0;
+                widget->getContentsMargins(NULL, &top, NULL, &bottom );
+
+                // also need to decrement default size further due to extra hard coded round corner
+                const int size = _size - 2;
+
+                // it seems arrow can be either to the top or the bottom. Adjust margins accordingly
+                if( top > bottom ) data << size - (top - bottom) << size << size << size;
+                else data << size << size << size - (bottom - top) << size;
+
+            } else {
+                data << _size << _size << _size << _size;
+            }
+
+        } else if( isToolBar( widget ) ) {
 
             data << _size << _size << _size << _size;
 
