@@ -34,8 +34,8 @@ public:
     virtual ~EglOnXBackend();
     virtual void screenGeometryChanged(const QSize &size);
     virtual SceneOpenGL::TexturePrivate *createBackendTexture(SceneOpenGL::Texture *texture);
-    virtual void prepareRenderingFrame();
-    virtual void endRenderingFrame(const QRegion &damage);
+    virtual QRegion prepareRenderingFrame();
+    virtual void endRenderingFrame(const QRegion &renderedRegion, const QRegion &damagedRegion);
 
 protected:
     virtual void present();
@@ -49,6 +49,7 @@ private:
     EGLSurface surface;
     EGLContext ctx;
     int surfaceHasSubPost;
+    int m_bufferAge;
     friend class EglTexture;
 };
 
