@@ -33,11 +33,11 @@ class Unmanaged
 {
     Q_OBJECT
 public:
-    Unmanaged(Workspace *ws);
+    explicit Unmanaged();
     bool windowEvent(XEvent* e);
     void release(bool on_shutdown = false);
     bool track(Window w);
-    static void deleteUnmanaged(Unmanaged* c, allowed_t);
+    static void deleteUnmanaged(Unmanaged* c);
     virtual int desktop() const;
     virtual QStringList activities() const;
     virtual QPoint clientPos() const;
