@@ -128,11 +128,12 @@ void Tasks::init()
     optimumCapacity.connectNotifySignal(this, SLOT(optimumCapacityChanged()));
 
     connect(m_declarativeWidget->rootObject(), SIGNAL(activateItem(int,bool)), this, SLOT(activateItem(int,bool)));
-    connect(m_declarativeWidget->rootObject(), SIGNAL(itemContextMenu(int)), this, SLOT(itemContextMenu(int)));
+    connect(m_declarativeWidget->rootObject(), SIGNAL(itemContextMenu(int)), this, SLOT(itemContextMenu(int)), Qt::QueuedConnection);
     connect(m_declarativeWidget->rootObject(), SIGNAL(itemMove(int,int)), this, SLOT(itemMove(int,int)));
     connect(m_declarativeWidget->rootObject(), SIGNAL(itemGeometryChanged(int,int,int,int,int)),
         this, SLOT(itemGeometryChanged(int,int,int,int,int)));
     connect(m_declarativeWidget->rootObject(), SIGNAL(itemNeedsAttention(bool)), this, SLOT(itemNeedsAttention(bool)));
+    connect(m_declarativeWidget->rootObject(), SIGNAL(presentWindows(int)), this, SLOT(presentWindows(int)));
 
     connect(KWindowSystem::self(), SIGNAL(activeWindowChanged(WId)), this, SLOT(handleActiveWindowChanged(WId)));
 
@@ -276,6 +277,18 @@ void Tasks::itemContextMenu(int id)
     menu->deleteLater();
 }
 
+void Tasks::contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
+{
+    QVariant ret;
+
+    QMetaObject::invokeMethod(m_declarativeWidget->rootObject(), "isTaskAt",
+        Q_RETURN_ARG(QVariant, ret), Q_ARG(QVariant, event->pos()));
+
+    if (!ret.toBool()) {
+        Plasma::Applet::contextMenuEvent(event);
+    }
+}
+
 void Tasks::itemHovered(int id, bool hovered)
 {
     TaskManager::AbstractGroupableItem* item = m_groupManager->rootGroup()->getMemberById(id);
@@ -358,6 +371,15 @@ void Tasks::itemNeedsAttention(bool needs)
     }
 }
 
+void Tasks::presentWindows(int groupParentId)
+{
+    TaskManager:: AbstractGroupableItem *item = m_groupManager->rootGroup()->getMemberById(groupParentId);
+
+    if (item) {
+        Plasma::WindowEffects::presentWindows(view()->winId(), QList<WId>::fromSet(item->winIds()));
+    }
+}
+
 void Tasks::handleActiveWindowChanged(WId activeWindow)
 {
     m_declarativeWidget->rootObject()->setProperty("activeWindowId", qulonglong(activeWindow));
