@@ -66,7 +66,7 @@ class Image : public Plasma::Wallpaper
          * Open the current slide in the default image application
          */
         void openSlide();
-        void updateBackground(const QImage &img);
+        void wallpaperRenderComplete(const QImage &img);
         void showFileDialog();
         void setFadeValue(qreal value);
         void configWidgetDestroyed();
@@ -89,6 +89,8 @@ class Image : public Plasma::Wallpaper
         void pathDirty(const QString &path);
         void pathDeleted(const QString &path);
         void backgroundsFound(const QStringList &paths, const QString &token);
+        bool checkSize();
+        void actuallyRenderWallpaper();
 
     protected:
         void init(const KConfigGroup &config);
@@ -119,6 +121,7 @@ class Image : public Plasma::Wallpaper
         QStringList m_slideshowBackgrounds;
         QStringList m_unseenSlideshowBackgrounds;
         QTimer m_timer;
+        QTimer m_delayedRenderTimer;
         QPixmap m_pixmap;
         QPixmap m_oldPixmap;
         QPixmap m_oldFadedPixmap;
